Cupped Set For Squezer 5/32 | Aircraft Spruce
Author: www.aircraftspruce.com
Description: Cupped Set For Squezer 5/32 For Swivel Hand Rivet Squeezer or any snap Type .187 Shank Diameter Squeezer
Keywords: CUPPED, SQUEEZER, SETS, FOR, INDIVIDUAL, AN470, RIVETS

Quick Shop
×
Length
Quantity
Your Cart
×

- Quantity
  Delete

Total (USD)
Add Options
×

Please check the boxes for the options that you would like to add. Leave all boxes unchecked for unit only.

- Photo may represent series and not specific product

- SHARE

## Cupped Set For Squezer 5/32

0 Reviews 0 Answered Questions
$11.75/Each
Quantity
Add to Wishlist View More In This Series →
Part# AT108AR-5/32
MFR Model# ATI108AR5/32
FREE Shipping Item qualifies for free outbound shipping. Please note other excluded items on the same order may incur a freight charge. Free shipping must be selected in cart for promotion to apply.
Eligible for Flat Rate Shipping Item qualifies for flat rate outbound shipping. Please note other excluded items on the same order may incur a freight charge. Flat Rate Shipping must be selected in cart for promotion to apply.
30 Day Risk Free Purchase
FREE Shipping + Returns Item qualifies for free outbound and return shipping. Please note other excluded items on the same order may incur a freight charge. Free shipping must be selected in cart for promotion to apply.
30 Day Risk Free Purchase
Flat Rate Shipping + FREE Returns Item qualifies for flat rate outbound and free return shipping. Please note other excluded items on the same order may incur a freight charge. Flat rate shipping must be selected in cart for promotion to apply. Flat rate shipping will not be reimbursed if item is returned.
30 Day Risk Free Purchase
Eligible for FREE Return Shipping Item qualifies for free outbound and return shipping. Please note other excluded items on the same order may incur a freight charge. Free shipping must be selected in cart for promotion to apply.
JUMP TO

- JUMP TO
- Overview
- Reviews
- Q&A
- View in Catalog

## Overview

For Swivel Hand Rivet Squeezer or any snap Type .187 Shank Diameter Squeezer Instructions for Selecting Rivet Sets: To develop maximum power, the riveter must drive the rivet near the end of the riveter's stroke.For maximum power the combined length of the two rivet sets must be of the correct length. Determine the correct length as follows: WHEN TWO CUPPED RIVET SETS ARE USED: The sum of the two rivet sets "L" dimension should equal the closed height dimension of the yoke minus the total thickness of the material being used. WHEN TWO FLUSH SETS ARE USED: The sum of the two rivet sets "L" dimension should equal the closed height dimesion of the yoke minus the overall length of the rivet after it is driven. WHEN ONE CUPPED SET & ONE FLUSH SET ARE USED: The sum of the two rivet sets "L" dimension should equal the closed height dimension of the yoke minus the total thickness fo the material being riveted and the height fo the finished rivet head driven by the flush set. If necessary, select rivet sets a little short and shim to proper length with hardened shims listed in the table. The closed height dimension of the yoke referred to above is the opening available when jaws of plunger are in extreme closed or forward position with both rivet sets in place. Note: To determine correct set when ordering, select rivet size then body length.

| WARNING: Cancer and Reproductive Harm - www.P65Warnings.ca.gov.

- Frequently Purchased With
- Customers Also Viewed

Cupped Set For Squeezer 3/16
$11.75
Quick Shop
Cupped Squeezer Set 1/8 (1Pc)
$11.75
Quick Shop
Squeezer Set AT108AP-1/8 1 Pc
$12.90
Quick Shop
Cupped Set For Squeezer 1/8
$12.90
Quick Shop
Cupped Squeezer Set 3/32 (1Pc)
$11.85
Quick Shop
Squeezer Set AT108AP-5/32 1 Pc
$11.85
Quick Shop
Cupped Squeezer Set 5/32 (1Pc)
$11.95
Quick Shop
Cupped Set For Squeezer 5/32
$11.75
Quick Shop
Cupped Set For Squeezer As
$11.75
Quick Shop
Squeezer Set AT108AP-3/32 1 Pc
$11.50
Quick Shop
Cupped Squeezer Set 3/16 (1Pc)
$9.65
Quick Shop
Cupped Squeezer Set 1/8 (1Pc)
$11.95
Quick Shop
Straight Shank Flute Chucking Reamer - Size 3
$14.75
Quick Shop
Standard Duty Deburring & Scraping Kit
$45.80
Quick Shop
Bucking Blocks
$42.75
Quick Shop
Rivet Sets Straight .401 Shank (AN470)
$41.50
Quick Shop
At 100A Straight Rivet 5/32 Inch
$9.85
Quick Shop
Edge Marker Block
$21.70
Quick Shop
Flush Swivel Rivet Set
$59.75
Quick Shop
Amp Pro Crimper II Hand Tool
$208.00
Quick Shop
Straight Shank Flute Chucking Reamer - Size 12
$14.50
Quick Shop
3X Rivet Gun Kit
$357.00
Quick Shop
Shop Head Rivet Gauge Set
$24.50
Quick Shop
Rivet Removal Tool
$3.95
Quick Shop
Shaviv Deburring Tool Mango II E Heavy Duty With Telescope E Holder And Three Blades
$17.95
Quick Shop
Rivet Sets For Squeezer (Flush & Cupped)
$4.35
Quick Shop
Dogleg Deburring Tool
$20.65
Quick Shop
12 Inch Long Drill Bits
$10.50
Quick Shop
At108AN Straight Rivet 3/16 Inch
$9.65
Quick Shop
Tatco Squeezer Yokes
$93.75
Quick Shop
Cl Series Cleco Sheet Holders
$3.25
Quick Shop

## Reviews

Submit a Review

## Q&A

Submit

Please note, Aircraft Spruce's personnel are not certified aircraft mechanics and can only provide general support and ideas, which should not be relied upon or implemented in lieu of consulting an A&P or other qualified technician. Aircraft Spruce assumes no responsibility or liability for any issue or problem which may arise from any repair, modification or other work done from this knowledge base. Any product eligibility information provided here is based on general application guides and we recommend always referring to your specific aircraft parts manual, the parts manufacturer or consulting with a qualified mechanic.

## View in Catalog

View in Catalog

Question About: | Cupped Set For Squezer 5/32
Email: |
Your Name: |
Question: |
| Submit

Review Product: | Cupped Set For Squezer 5/32
Email: |
Your Name: |
Rating: |
Comments: |
| Submit